ProfileFrame class abstract

Encapsulates the data around a parser profile.

Constructors

ProfileFrame()

Properties

count → int
The number of times this parser was activated.
no setter
elapsed → Duration
The total elapsed time in this parser and its children.
no setter
hashCode → int
The hash code for this object.
no setterinherited
parser → Parser
The parser of this frame.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited