ProgressFrame class abstract

Encapsulates the data around a parser progress.

Constructors

ProgressFrame()

Properties

context → Context
The activation context of this frame.
no setter
hashCode → int
The hash code for this object.
no setterinherited
parser → Parser
The parser of this frame.
no setter
position → int
The current position in the input.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited