TraceEvent class abstract

Encapsulates the entry and exit data around a parser trace.

Constructors

TraceEvent()

Properties

context → Context
The activation context of this event.
no setter
hashCode → int
The hash code for this object.
no setterinherited
level → int
The nesting level of this event.
no setter
parent → TraceEvent?
The parent trace event.
no setter
parser → Parser
The parser of this event.
no setter
result → Result?
The result if this is an exit event, otherwise null.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited