LinterIssue class

Encapsulates a single linter issue.

Annotations
  • @immutable

Constructors

LinterIssue(LinterRule rule, Parser parser, String description)
Constructs a new linter issue.
const

Properties

description → String
Detailed explanation of the issue.
final
hashCode → int
The hash code for this object.
no setterinherited
parser → Parser
Parser object with the issue.
final
rule → LinterRule
Rule that identified the issue.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
Title of the issue.
no setter
type → LinterType
Severity of the issue.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited