run abstract method
Executes this rule using the provided analyzer on a parser.
Expected to call callback zero or more times as issues are detected.
Implementation
void run(Analyzer analyzer, Parser parser, LinterCallback callback);
Executes this rule using the provided analyzer on a parser.
Expected to call callback zero or more times as issues are detected.
void run(Analyzer analyzer, Parser parser, LinterCallback callback);