run<R> abstract method
Executes this rule using the provided analyzer on a parser.
Implementation
void run<R>(Analyzer analyzer, Parser<R> parser, ReplaceParser<R> replace);
Executes this rule using the provided analyzer on a parser.
void run<R>(Analyzer analyzer, Parser<R> parser, ReplaceParser<R> replace);